Module waves

Module waves 

Wave computation for parallel task execution.

Computes execution waves using topological sort, grouping tasks that can run in parallel based on their dependencies. Wave computation for parallel task execution.

Computes execution waves using Kahn’s algorithm (topological sort with level assignment), grouping tasks that can run in parallel based on their dependencies.

Structs

Wave
A wave of tasks that can be executed in parallel
WaveResult
Result of wave computation

Functions

compute_waves
Compute execution waves using Kahn’s algorithm (topological sort with level assignment) When processing tasks from multiple phases, task IDs are expected to be namespaced
detect_id_collisions
Detect ID collisions when merging tasks from multiple phases Returns a list of (local_id, Vec) for IDs that appear in multiple tags