pub struct EventPublisher { /* private fields */ }Expand description
Event publisher for SCUD task management events.
Manages ZMQ sockets for publishing events and handling requests.
Implementations
Sourceimpl EventPublisher
impl EventPublisher
Sourcepub fn receive_request(&self) -> Result<String>
pub fn receive_request(&self) -> Result<String>
Receive a request message.
This is a blocking call that waits for a request.
Returns
A Result containing the received message or an error